@@ -21,6 +21,7 @@
 
 #include "modsecurity/transaction.h"
 #include "modsecurity/rule_message.h"
+#include "modsecurity/rules.h"
 
 namespace modsecurity {
 namespace actions {
@@ -29,6 +30,9 @@ namespace actions {
 bool AuditLog::evaluate(Rule *rule, Transaction *transaction,
     std::shared_ptr<RuleMessage> rm) {
     rm->m_noAuditLog = false;
+    ms_dbg_a(transaction, 9, "Saving transaction to logs");
+    rm->m_saveMessage = true;
+
     return true;
 }
 
