@@ -38,7 +38,8 @@ bool Redirect::evaluate(Rule *rule, Transaction *transaction,
     std::shared_ptr<RuleMessage> rm) {
     std::string m_urlExpanded(m_string->evaluate(transaction));
     /* if it was changed before, lets keep it. */
-    if (transaction->m_it.status == 200) {
+    if (transaction->m_it.status == 200
+        || (!(transaction->m_it.status <= 307 && transaction->m_it.status >= 301))) {
         transaction->m_it.status = m_status;
     }
 
@@ -46,10 +47,10 @@ bool Redirect::evaluate(Rule *rule, Transaction *transaction,
     transaction->m_it.url = strdup(m_urlExpanded.c_str());
     transaction->m_it.disruptive = true;
     intervention::freeLog(&transaction->m_it);
+    rm->m_isDisruptive = true;
     transaction->m_it.log = strdup(
         rm->log(RuleMessage::LogMessageInfo::ClientLogMessageInfo).c_str());
 
-    rm->m_isDisruptive = true;
     return true;
 }
 
