@@ -67,10 +67,8 @@ bool InitCol::evaluate(Rule *rule, Transaction *t) {
         return false;
     }
 
-#ifndef NO_LOGS
-    t->debug(5, "Collection `" + m_collection_key + "' initialized with " \
+    ms_dbg_a(t, 5, "Collection `" + m_collection_key + "' initialized with " \
         "value: " + collectionName);
-#endif
 
     return true;
 }
