@@ -14,8 +14,11 @@
  */
 
 #include <string>
+#include <memory>
+#include <utility>
 
 #include "modsecurity/actions/action.h"
+#include "src/run_time_string.h"
 
 #ifndef SRC_ACTIONS_SET_UID_H_
 #define SRC_ACTIONS_SET_UID_H_
@@ -32,11 +35,15 @@ class SetUID : public Action {
     explicit SetUID(std::string _action)
         : Action(_action) { }
 
+    explicit SetUID(std::unique_ptr<RunTimeString> z)
+        : Action("setuid", RunTimeOnlyIfMatchKind),
+            m_string(std::move(z)) { }
+
     bool evaluate(Rule *rule, Transaction *transaction) override;
     bool init(std::string *error) override;
 
  private:
-    std::string m_collection_key;
+    std::unique_ptr<RunTimeString> m_string;
 };
 
 
