@@ -22,6 +22,7 @@
 #include "modsecurity/actions/action.h"
 #include "modsecurity/transaction.h"
 #include "modsecurity/rule.h"
+#include "modsecurity/rules.h"
 #include "src/utils/string.h"
 #include "modsecurity/rule_message.h"
 
@@ -72,11 +73,9 @@ bool Severity::init(std::string *error) {
 
 bool Severity::evaluate(Rule *rule, Transaction *transaction,
     std::shared_ptr<RuleMessage> rm) {
-#ifndef NO_LOGS
-    transaction->debug(9, "This rule severity is: " + \
+    ms_dbg_a(transaction, 9, "This rule severity is: " + \
         std::to_string(this->m_severity) + " current transaction is: " + \
         std::to_string(transaction->m_highestSeverityAction));
-#endif
 
     rm->m_severity = m_severity;
 
@@ -84,8 +83,6 @@ bool Severity::evaluate(Rule *rule, Transaction *transaction,
         transaction->m_highestSeverityAction = this->m_severity;
     }
 
-    transaction->m_variableRule.set("severity", std::to_string(m_severity), 0);
-
     return true;
 }
 
