@@ -59,10 +59,7 @@ std::string Tag::getName(Transaction *transaction) {
 bool Tag::evaluate(Rule *rule, Transaction *transaction,
     std::shared_ptr<RuleMessage> rm) {
     std::string tag = getName(transaction);
-
-#ifndef NO_LOGS
-    transaction->debug(9, "Rule tag: " + tag);
-#endif
+    ms_dbg_a(transaction, 9, "Rule tag: " + tag);
 
     rm->m_tags.push_back(tag);
 
