@@ -17,6 +17,8 @@
 #define SRC_OPERATORS_FUZZY_HASH_H_
 
 #include <string>
+#include <memory>
+#include <utility>
 
 #ifdef WITH_SSDEEP
 #include <fuzzy.h>
@@ -36,12 +38,8 @@ struct fuzzy_hash_chunk {
 class FuzzyHash : public Operator {
  public:
     /** @ingroup ModSecurity_Operator */
-    FuzzyHash(std::string o, std::string p, bool n)
-        : Operator(o, p, n),
-        m_head(NULL),
-        m_threshold(0) { }
-    explicit FuzzyHash(std::string param)
-        : Operator("FuzzyHash", param),
+    explicit FuzzyHash(std::unique_ptr<RunTimeString> param)
+        : Operator("FuzzyHash", std::move(param)),
         m_head(NULL),
         m_threshold(0) { }
     ~FuzzyHash();
