@@ -17,6 +17,8 @@
 #define SRC_OPERATORS_INSPECT_FILE_H_
 
 #include <string>
+#include <memory>
+#include <utility>
 
 #include "src/operators/operator.h"
 #include "src/engine/lua.h"
@@ -28,12 +30,8 @@ namespace operators {
 class InspectFile : public Operator {
  public:
     /** @ingroup ModSecurity_Operator */
-    InspectFile(std::string o, std::string p, bool n)
-        : Operator(o, p, n),
-        m_file(""),
-        m_isScript(false) { }
-    explicit InspectFile(std::string param)
-        : Operator("InspectFile", param),
+    explicit InspectFile(std::unique_ptr<RunTimeString> param)
+        : Operator("InspectFile", std::move(param)),
         m_file(""),
         m_isScript(false) { }
 
