@@ -18,13 +18,13 @@
 #include <string>
 
 #include "src/operators/operator.h"
-#include "src/macro_expansion.h"
+
 
 namespace modsecurity {
 namespace operators {
 
 bool Le::evaluate(Transaction *transaction, const std::string &input) {
-    std::string p = MacroExpansion::expand(m_param, transaction);
+    std::string p(m_string->evaluate(transaction));
 
     bool le = atoll(input.c_str()) <= atoll(p.c_str());
 
