@@ -58,6 +58,7 @@
 #include "src/operators/verify_cc.h"
 #include "src/operators/verify_cpf.h"
 #include "src/operators/verify_ssn.h"
+#include "src/operators/verify_svnr.h"
 #include "src/operators/within.h"
 #include "src/operators/unconditional_match.h"
 
@@ -68,13 +69,6 @@ namespace modsecurity {
 namespace operators {
 
 
-bool Operator::debug(Transaction *transaction, int x, std::string a) {
-#ifndef NO_LOGS
-    transaction->debug(x, a);
-#endif
-    return true;
-}
-
 bool Operator::evaluateInternal(Transaction *transaction,
     Rule *rule, const std::string& a, std::shared_ptr<RuleMessage> rm) {
     bool res = evaluate(transaction, rule, a, rm);
@@ -138,13 +132,8 @@ std::string Operator::resolveMatchMessage(Transaction *t,
 
 
 bool Operator::evaluate(Transaction *transaction, const std::string& a) {
-#ifndef NO_LOGS
-    if (transaction) {
-        transaction->debug(2, "Operator: " + this->m_op + \
-            " is not implemented or malfunctioning.");
-    }
-#endif
-
+    ms_dbg_a(transaction, 2, "Operator: " + m_op + \
+        " is not implemented or malfunctioning.");
     return true;
 }
 
@@ -197,13 +186,14 @@ Operator *Operator::instantiate(std::string op, std::string param_str) {
     IF_MATCH(verifycc) { return new VerifyCC(std::move(param)); }
     IF_MATCH(verifycpf) { return new VerifyCPF(std::move(param)); }
     IF_MATCH(verifyssn) { return new VerifySSN(std::move(param)); }
+    IF_MATCH(verifysvnr) { return new VerifySVNR(std::move(param)); }
     IF_MATCH(within) { return new Within(std::move(param)); }
 
     IF_MATCH(unconditionalmatch) {
         return new UnconditionalMatch();
     }
 
-    std::invalid_argument("Operator not found.");
+    throw std::invalid_argument("Operator not found.");
 }
 
 }  // namespace operators
