@@ -84,7 +84,7 @@ void Pm::postOrderTraversal(acmp_btree_node_t *node) {
 
 bool Pm::evaluate(Transaction *transaction, Rule *rule,
     const std::string &input, std::shared_ptr<RuleMessage> ruleMessage) {
-    int rc = 0;
+    int rc = -1;
     ACMPT pt;
     pt.parser = m_p;
     pt.ptr = NULL;
@@ -97,20 +97,20 @@ bool Pm::evaluate(Transaction *transaction, Rule *rule,
     pthread_mutex_unlock(&m_lock);
 #endif
 
-    if (rc > 0 && transaction) {
+    if (rc >= 0 && transaction) {
         std::string match_(match);
         logOffset(ruleMessage, rc - match_.size() + 1, match_.size());
         transaction->m_matched.push_back(match_);
     }
 
-    if (rule && rule->m_containsCaptureAction && transaction && rc) {
+    if (rule && rule->m_containsCaptureAction && transaction && rc >= 0) {
         transaction->m_collections.m_tx_collection->storeOrUpdateFirst("0",
             std::string(match));
         ms_dbg_a(transaction, 7, "Added pm match TX.0: " + \
             std::string(match));
     }
 
-    return rc > 0;
+    return rc >= 0;
 }
 
 
