@@ -38,7 +38,6 @@ bool Rx::init(const std::string &arg, std::string *error) {
 
 bool Rx::evaluate(Transaction *transaction, Rule *rule,
     const std::string& input, std::shared_ptr<RuleMessage> ruleMessage) {
-    SMatch match;
     std::list<SMatch> matches;
     Regex *re;
 
@@ -59,16 +58,16 @@ bool Rx::evaluate(Transaction *transaction, Rule *rule,
         matches.reverse();
         for (const SMatch& a : matches) {
             transaction->m_collections.m_tx_collection->storeOrUpdateFirst(
-                std::to_string(i), a.match);
+                std::to_string(i), a.str());
             ms_dbg_a(transaction, 7, "Added regex subexpression TX." +
-                std::to_string(i) + ": " + a.match);
-            transaction->m_matched.push_back(a.match);
+                std::to_string(i) + ": " + a.str());
+            transaction->m_matched.push_back(a.str());
             i++;
         }
     }
 
     for (const auto & i : matches) {
-        logOffset(ruleMessage, i.m_offset, i.m_length);
+        logOffset(ruleMessage, i.offset(), i.str().size());
     }
 
     if (m_string->m_containsMacro) {
