@@ -63,9 +63,7 @@ class ValidateDTD : public Operator {
         if (len > 0) {
             s = "XML Error: " + std::string(buf);
         }
-#ifndef NO_LOGS
-        t->debug(4, s);
-#endif
+        ms_dbg_a(t, 4, s);
     }
 
 
@@ -82,9 +80,7 @@ class ValidateDTD : public Operator {
         if (len > 0) {
             s = "XML Warning: " + std::string(buf);
         }
-#ifndef NO_LOGS
-        t->debug(4, s);
-#endif
+        ms_dbg_a(t, 4, s);
     }
 
 
@@ -93,7 +89,7 @@ class ValidateDTD : public Operator {
 
  private:
     std::string m_resource;
-    xmlDtdPtr m_dtd;
+    xmlDtdPtr m_dtd = NULL;
 #endif
 };
 
