@@ -70,7 +70,7 @@ Multipart::Multipart(std:: string header, Transaction *transaction)
 
 Multipart::~Multipart() {
     ms_dbg_a(m_transaction, 4,
-        "Multipart: Cleanup started (remove files " \
+        "Multipart: Cleanup started (keep files set to " \
         + RulesProperties::configBooleanString(
             m_transaction->m_rules->m_uploadKeepFiles) \
         + ")");
@@ -96,7 +96,7 @@ Multipart::~Multipart() {
                             + strerror(errno) + ")");
                     } else {
                         ms_dbg_a(m_transaction, 4,
-                            "Multipart: Failed to delete file (part) \"" \
+                            "Multipart: file deleted successfully (part) \"" \
                             + m->m_tmp_file_name + "\"");
                     }
 
@@ -158,41 +158,27 @@ int Multipart::boundary_characters_valid(const char *boundary) {
     }
 
     while ((c = *p) != '\0') {
-        /* Control characters and space not allowed. */
-        if (c < 32) {
+        // Check against allowed list defined in RFC2046 page 22
+        if (!(
+            ('0' <= c && c <= '9')
+            || ('A' <= c && c <= 'Z')
+            || ('a' <= c && c <= 'z')
+            || (c == ' ' && *(p + 1) != '\0') // space allowed, but not as last character
+            || c == '\''
+            || c == '('
+            || c == ')'
+            || c == '+'
+            || c == '_'
+            || c == ','
+            || c == '-'
+            || c == '.'
+            || c == '/'
+            || c == ':'
+            || c == '='
+            || c == '?'
+            )) {
             return 0;
         }
-
-        /* Non-ASCII characters not allowed. */
-        if (c > 126) {
-            return 0;
-        }
-
-        switch (c) {
-            /* Special characters not allowed. */
-            case '(' :
-            case ')' :
-            case '<' :
-            case '>' :
-            case '@' :
-            case ',' :
-            case ';' :
-            case ':' :
-            case '\\' :
-            case '"' :
-            case '/' :
-            case '[' :
-            case ']' :
-            case '?' :
-            case '=' :
-                return 0;
-                break;
-
-            default :
-                /* Do nothing. */
-                break;
-        }
-
         p++;
     }
 
@@ -530,7 +516,7 @@ int Multipart::process_part_data(std::string *error, size_t offset) {
 
                 ms_dbg_a(m_transaction, 4,
                     "Multipart: Created temporary file " \
-                    + std::to_string(m_nfiles) + " (mode 04o): " \
+                    + std::to_string(m_nfiles) + " (mode o" + std::to_string(m_transaction->m_rules->m_uploadFileMode.m_value) + "): " \
                     + m_mpp->m_tmp_file_name);
             }
 
@@ -1094,8 +1080,8 @@ int Multipart::multipart_complete(std::string *error) {
             m_transaction->m_variableFiles.set(m->m_filename,
                 m->m_filename, m->m_filenameOffset);
 
-            m_transaction->m_variableFilesNames.set(m->m_filename,
-                m->m_filename, m->m_filenameOffset);
+            m_transaction->m_variableFilesNames.set(m->m_name,
+                m->m_name, m->m_nameOffset);
 
             m_transaction->m_variableFilesSizes.set(m->m_name,
                 std::to_string(m->m_tmp_file_size.first),
