@@ -31,6 +31,32 @@ RulesExceptions::~RulesExceptions() {
 }
 
 
+bool RulesExceptions::loadUpdateActionById(double id,
+    std::unique_ptr<std::vector<std::unique_ptr<actions::Action> > > actions,
+    std::string *error) {
+
+    for (auto &a : *actions) {
+        if (a->action_kind == actions::Action::ConfigurationKind) {
+            std::cout << "General failure, action: " << a->m_name;
+            std::cout << " has not expected to be used with UpdateActionByID.";
+            std::cout << std::endl;
+        } else if (a->action_kind
+            == actions::Action::RunTimeBeforeMatchAttemptKind) {
+            m_action_pre_update_target_by_id.emplace(std::pair<double,
+                std::unique_ptr<actions::Action>>(id , std::move(a)));
+        } else if (a->action_kind == actions::Action::RunTimeOnlyIfMatchKind) {
+            m_action_pos_update_target_by_id.emplace(std::pair<double,
+                std::unique_ptr<actions::Action>>(id , std::move(a)));
+        } else {
+            std::cout << "General failure, action: " << a->m_name;
+            std::cout << " has an unknown type." << std::endl;
+        }
+    }
+
+    return true;
+}
+
+
 bool RulesExceptions::loadRemoveRuleByMsg(const std::string &msg,
     std::string *error) {
     m_remove_rule_by_msg.push_back(msg);
@@ -48,12 +74,12 @@ bool RulesExceptions::loadRemoveRuleByTag(const std::string &msg,
 
 
 bool RulesExceptions::loadUpdateTargetByMsg(const std::string &msg,
-    std::unique_ptr<std::vector<std::unique_ptr<Variables::Variable> > > var,
+    std::unique_ptr<std::vector<std::unique_ptr<variables::Variable> > > var,
     std::string *error) {
     for (auto &i : *var) {
         m_variable_update_target_by_msg.emplace(
             std::pair<std::shared_ptr<std::string>,
-            std::unique_ptr<Variables::Variable>>(
+            std::unique_ptr<variables::Variable>>(
                 std::make_shared<std::string>(msg),
                 std::move(i)));
     }
@@ -63,14 +89,15 @@ bool RulesExceptions::loadUpdateTargetByMsg(const std::string &msg,
 
 
 bool RulesExceptions::loadUpdateTargetByTag(const std::string &tag,
-    std::unique_ptr<std::vector<std::unique_ptr<Variables::Variable> > > var,
+    std::unique_ptr<std::vector<std::unique_ptr<variables::Variable> > > var,
     std::string *error) {
 
     for (auto &i : *var) {
         m_variable_update_target_by_tag.emplace(
             std::pair<std::shared_ptr<std::string>,
-                std::unique_ptr<Variables::Variable>>(
-                    std::make_shared<std::string>(tag), std::move(i)));
+                std::unique_ptr<variables::Variable>>(
+                    std::make_shared<std::string>(tag),
+                    std::move(i)));
     }
 
     return true;
@@ -78,13 +105,14 @@ bool RulesExceptions::loadUpdateTargetByTag(const std::string &tag,
 
 
 bool RulesExceptions::loadUpdateTargetById(double id,
-    std::unique_ptr<std::vector<std::unique_ptr<Variables::Variable> > > var,
+    std::unique_ptr<std::vector<std::unique_ptr<variables::Variable> > > var,
     std::string *error) {
 
     for (auto &i : *var) {
         m_variable_update_target_by_id.emplace(
             std::pair<double,
-                std::unique_ptr<Variables::Variable>>(id , std::move(i)));
+                std::unique_ptr<variables::Variable>>(id,
+                std::move(i)));
     }
 
     return true;
@@ -194,22 +222,36 @@ bool RulesExceptions::merge(RulesExceptions *from) {
     for (auto &p : from->m_variable_update_target_by_tag) {
         m_variable_update_target_by_tag.emplace(
             std::pair<std::shared_ptr<std::string>,
-            std::unique_ptr<Variables::Variable>>(p.first,
-                std::move(p.second)));
+            std::shared_ptr<variables::Variable>>(p.first,
+                p.second));
     }
 
     for (auto &p : from->m_variable_update_target_by_msg) {
         m_variable_update_target_by_msg.emplace(
             std::pair<std::shared_ptr<std::string>,
-            std::unique_ptr<Variables::Variable>>(p.first,
-                std::move(p.second)));
+            std::shared_ptr<variables::Variable>>(p.first,
+                p.second));
     }
 
     for (auto &p : from->m_variable_update_target_by_id) {
         m_variable_update_target_by_id.emplace(
             std::pair<double,
-                std::unique_ptr<Variables::Variable>>(p.first,
-                    std::move(p.second)));
+                std::shared_ptr<variables::Variable>>(p.first,
+                    p.second));
+    }
+
+    for (auto &p : from->m_action_pos_update_target_by_id) {
+        m_action_pos_update_target_by_id.emplace(
+            std::pair<double,
+                std::shared_ptr<actions::Action>>(p.first,
+                    p.second));
+    }
+
+    for (auto &p : from->m_action_pre_update_target_by_id) {
+        m_action_pre_update_target_by_id.emplace(
+            std::pair<double,
+                std::shared_ptr<actions::Action>>(p.first,
+                    p.second));
     }
 
     for (auto &p : from->m_remove_rule_by_msg) {
