@@ -27,21 +27,14 @@
 namespace modsecurity {
 
 class Transaction;
-namespace Variables {
+namespace variables {
 
-class ArgsCombinedSize : public Variable {
- public:
-    ArgsCombinedSize()
-        : Variable("ARGS_COMBINED_SIZE") { }
 
-    void evaluate(Transaction *transaction,
-        Rule *rule,
-        std::vector<const VariableValue *> *l) {
-        transaction->m_variableARGScombinedSize.evaluate(l);
-    }
-};
+DEFINE_VARIABLE(ArgsCombinedSize, ARGS_COMBINED_SIZE,
+    m_variableARGScombinedSize)
 
-}  // namespace Variables
+
+}  // namespace variables
 }  // namespace modsecurity
 
 #endif  // SRC_VARIABLES_ARGS_COMBINED_SIZE_H_
