@@ -27,21 +27,14 @@
 namespace modsecurity {
 
 class Transaction;
-namespace Variables {
+namespace variables {
 
-class FilesCombinedSize : public Variable {
- public:
-    FilesCombinedSize()
-        : Variable("FILES_COMBINED_SIZE") { }
 
-    void evaluate(Transaction *transaction,
-        Rule *rule,
-        std::vector<const VariableValue *> *l) {
-        transaction->m_variableFilesCombinedSize.evaluate(l);
-    }
-};
+DEFINE_VARIABLE(FilesCombinedSize, FILES_COMBINED_SIZE,
+    m_variableFilesCombinedSize)
 
-}  // namespace Variables
+
+}  // namespace variables
 }  // namespace modsecurity
 
 #endif  // SRC_VARIABLES_FILES_COMBINED_SIZE_H_
