@@ -14,10 +14,11 @@
  */
 
 #include <iostream>
-#include <string>
-#include <vector>
 #include <list>
+#include <memory>
+#include <string>
 #include <utility>
+#include <vector>
 
 #ifndef SRC_VARIABLES_IP_H_
 #define SRC_VARIABLES_IP_H_
@@ -28,7 +29,7 @@
 namespace modsecurity {
 
 class Transaction;
-namespace Variables {
+namespace variables {
 
 
 class Ip_DictElement : public Variable {
@@ -40,9 +41,9 @@ class Ip_DictElement : public Variable {
     void evaluate(Transaction *t,
         Rule *rule,
         std::vector<const VariableValue *> *l) override {
-        t->m_collections.m_ip_collection->resolveMultiMatches(m_dictElement,
-            t->m_collections.m_ip_collection_key, l);
-
+        t->m_collections.m_ip_collection->resolveMultiMatches(
+            m_name, t->m_collections.m_ip_collection_key,
+            t->m_rules->m_secWebAppId.m_value, l, m_keyExclusion);
     }
 
     std::string m_dictElement;
@@ -57,27 +58,27 @@ class Ip_NoDictElement : public Variable {
     void evaluate(Transaction *t,
         Rule *rule,
         std::vector<const VariableValue *> *l) override {
-        t->m_collections.m_ip_collection->resolveMultiMatches(m_name,
-            t->m_collections.m_ip_collection_key, l);
+        t->m_collections.m_ip_collection->resolveMultiMatches("",
+            t->m_collections.m_ip_collection_key,
+            t->m_rules->m_secWebAppId.m_value, l, m_keyExclusion);
     }
 };
 
 
-class Ip_DictElementRegexp : public Variable {
+class Ip_DictElementRegexp : public VariableRegex {
  public:
     explicit Ip_DictElementRegexp(std::string dictElement)
-        : Variable("IP:regex(" + dictElement + ")"),
-        m_r(dictElement),
-        m_dictElement("IP:" + dictElement) { }
+        : VariableRegex("IP", dictElement),
+        m_dictElement(dictElement) { }
 
     void evaluate(Transaction *t,
         Rule *rule,
         std::vector<const VariableValue *> *l) override {
-        t->m_collections.m_ip_collection->resolveRegularExpression(m_dictElement,
-            t->m_collections.m_ip_collection_key, l);
+        t->m_collections.m_ip_collection->resolveRegularExpression(
+            m_dictElement, t->m_collections.m_ip_collection_key,
+            t->m_rules->m_secWebAppId.m_value, l, m_keyExclusion);
     }
 
-    Utils::Regex m_r;
     std::string m_dictElement;
 };
 
@@ -92,26 +93,31 @@ class Ip_DynamicElement : public Variable {
         Rule *rule,
         std::vector<const VariableValue *> *l) override {
         std::string string = m_string->evaluate(t);
-        t->m_collections.m_ip_collection->resolveMultiMatches("IP:" + string,
-            t->m_collections.m_ip_collection_key, l);
+        t->m_collections.m_ip_collection->resolveMultiMatches(
+            string,
+            t->m_collections.m_ip_collection_key,
+            t->m_rules->m_secWebAppId.m_value, l, m_keyExclusion);
     }
 
     void del(Transaction *t, std::string k) {
         t->m_collections.m_ip_collection->del(k,
-            t->m_collections.m_ip_collection_key);
+            t->m_collections.m_ip_collection_key,
+            t->m_rules->m_secWebAppId.m_value);
     }
 
     void storeOrUpdateFirst(Transaction *t, std::string var,
         std::string value) {
         t->m_collections.m_ip_collection->storeOrUpdateFirst(
-            var, t->m_collections.m_ip_collection_key, value);
+            var, t->m_collections.m_ip_collection_key,
+            t->m_rules->m_secWebAppId.m_value,
+            value);
     }
 
     std::unique_ptr<RunTimeString> m_string;
 };
 
 
-}  // namespace Variables
+}  // namespace variables
 }  // namespace modsecurity
 
 #endif  // SRC_VARIABLES_IP_H_
