@@ -27,21 +27,14 @@
 namespace modsecurity {
 
 class Transaction;
-namespace Variables {
+namespace variables {
 
-class MultipartBoundaryQuoted : public Variable {
- public:
-    MultipartBoundaryQuoted()
-        : Variable("MULTIPART_BOUNDARY_QUOTED") { }
 
-    void evaluate(Transaction *transaction,
-        Rule *rule,
-        std::vector<const VariableValue *> *l) {
-        transaction->m_variableMultipartBoundaryQuoted.evaluate(l);
-    }
-};
+DEFINE_VARIABLE(MultipartBoundaryQuoted, MULTIPART_BOUNDARY_QUOTED,
+    m_variableMultipartBoundaryQuoted)
 
-}  // namespace Variables
+
+}  // namespace variables
 }  // namespace modsecurity
 
 #endif  // SRC_VARIABLES_MULTIPART_BOUNDARY_QUOTED_H_
