@@ -27,21 +27,14 @@
 namespace modsecurity {
 
 class Transaction;
-namespace Variables {
+namespace variables {
 
-class MultipartInvalidPart : public Variable {
- public:
-    MultipartInvalidPart()
-        : Variable("MULTIPART_INVALID_PART") { }
 
-    void evaluate(Transaction *transaction,
-        Rule *rule,
-        std::vector<const VariableValue *> *l) {
-        transaction->m_variableMultipartInvalidPart.evaluate(l);
-    }
-};
+DEFINE_VARIABLE(MultipartInvalidPart, MULTIPART_INVALID_PART,
+    m_variableMultipartInvalidHeaderFolding)
 
-}  // namespace Variables
+
+}  // namespace variables
 }  // namespace modsecurity
 
 #endif  // SRC_VARIABLES_MULTIPART_INVALID_PART_H_
