@@ -27,21 +27,13 @@
 namespace modsecurity {
 
 class Transaction;
-namespace Variables {
+namespace variables {
 
-class MultipartLFLine : public Variable {
- public:
-    MultipartLFLine()
-        : Variable("MULTIPART_LF_LINE") { }
 
-    void evaluate(Transaction *transaction,
-        Rule *rule,
-        std::vector<const VariableValue *> *l) {
-        transaction->m_variableMultipartLFLine.evaluate(l);
-    }
-};
+DEFINE_VARIABLE(MultipartLFLine, MULTIPART_LF_LINE, m_variableMultipartLFLine)
 
-}  // namespace Variables
+
+}  // namespace variables
 }  // namespace modsecurity
 
 #endif  // SRC_VARIABLES_MULTIPART_LF_LINE_H_
