@@ -27,21 +27,13 @@
 namespace modsecurity {
 
 class Transaction;
-namespace Variables {
+namespace variables {
 
-class PathInfo : public Variable {
- public:
-    PathInfo()
-        : Variable("PATH_INFO") { }
 
-    void evaluate(Transaction *transaction,
-        Rule *rule,
-        std::vector<const VariableValue *> *l) {
-        transaction->m_variablePathInfo.evaluate(l);
-    }
-};
+DEFINE_VARIABLE(PathInfo, PATH_INFO, m_variablePathInfo)
 
-}  // namespace Variables
+
+}  // namespace variables
 }  // namespace modsecurity
 
 #endif  // SRC_VARIABLES_PATH_INFO_H_
