@@ -27,21 +27,13 @@
 namespace modsecurity {
 
 class Transaction;
-namespace Variables {
+namespace variables {
 
-class QueryString : public Variable {
- public:
-    QueryString()
-        : Variable("QUERY_STRING") { }
 
-    void evaluate(Transaction *transaction,
-        Rule *rule,
-        std::vector<const VariableValue *> *l) {
-        transaction->m_variableQueryString.evaluate(l);
-    }
-};
+DEFINE_VARIABLE(QueryString, QUERY_STRING, m_variableQueryString)
 
-}  // namespace Variables
+
+}  // namespace variables
 }  // namespace modsecurity
 
 #endif  // SRC_VARIABLES_QUERY_STRING_H_
