@@ -27,21 +27,13 @@
 namespace modsecurity {
 
 class Transaction;
-namespace Variables {
+namespace variables {
 
-class ReqbodyError : public Variable {
- public:
-    ReqbodyError()
-        : Variable("REQBODY_ERROR") { }
 
-    void evaluate(Transaction *transaction,
-        Rule *rule,
-        std::vector<const VariableValue *> *l) {
-        transaction->m_variableReqbodyError.evaluate(l);
-    }
-};
+DEFINE_VARIABLE(ReqbodyError, REQBODY_ERROR, m_variableReqbodyError)
 
-}  // namespace Variables
+
+}  // namespace variables
 }  // namespace modsecurity
 
 #endif  // SRC_VARIABLES_REQBODY_ERROR_H_
