@@ -27,20 +27,13 @@
 namespace modsecurity {
 
 class Transaction;
-namespace Variables {
+namespace variables {
 
-class RequestProtocol : public Variable {
- public:
-    RequestProtocol()
-        : Variable("REQUEST_PROTOCOL") { }
-    void evaluate(Transaction *transaction,
-        Rule *rule,
-        std::vector<const VariableValue *> *l) {
-        transaction->m_variableRequestProtocol.evaluate(l);
-    }
-};
 
-}  // namespace Variables
+DEFINE_VARIABLE(RequestProtocol, REQUEST_PROTOCOL, m_variableRequestProtocol)
+
+
+}  // namespace variables
 }  // namespace modsecurity
 
 #endif  // SRC_VARIABLES_REQUEST_PROTOCOL_H_
