@@ -14,10 +14,11 @@
  */
 
 #include <iostream>
-#include <string>
-#include <vector>
 #include <list>
+#include <memory>
+#include <string>
 #include <utility>
+#include <vector>
 
 #ifndef SRC_VARIABLES_RESOURCE_H_
 #define SRC_VARIABLES_RESOURCE_H_
@@ -28,21 +29,21 @@
 namespace modsecurity {
 
 class Transaction;
-namespace Variables {
+namespace variables {
 
 
 class Resource_DictElement : public Variable {
  public:
     explicit Resource_DictElement(std::string dictElement)
         : Variable("RESOURCE:" + dictElement),
-        m_dictElement(dictElement) { }
+        m_dictElement("RESOURCE:" + dictElement) { }
 
     void evaluate(Transaction *t,
         Rule *rule,
         std::vector<const VariableValue *> *l) override {
-        t->m_collections.m_resource_collection->resolveMultiMatches(m_dictElement,
-            t->m_collections.m_resource_collection_key,
-            t->m_rules->m_secWebAppId.m_value, l);
+        t->m_collections.m_resource_collection->resolveMultiMatches(
+            m_name, t->m_collections.m_resource_collection_key,
+            t->m_rules->m_secWebAppId.m_value, l, m_keyExclusion);
     }
 
     std::string m_dictElement;
@@ -59,16 +60,15 @@ class Resource_NoDictElement : public Variable {
         std::vector<const VariableValue *> *l) override {
         t->m_collections.m_resource_collection->resolveMultiMatches(m_name,
             t->m_collections.m_resource_collection_key,
-            t->m_rules->m_secWebAppId.m_value, l);
+            t->m_rules->m_secWebAppId.m_value, l, m_keyExclusion);
     }
 };
 
 
-class Resource_DictElementRegexp : public Variable {
+class Resource_DictElementRegexp : public VariableRegex {
  public:
     explicit Resource_DictElementRegexp(std::string dictElement)
-        : Variable("RESOURCE:regex(" + dictElement + ")"),
-        m_r(dictElement),
+        : VariableRegex("RESOURCE:", dictElement),
         m_dictElement(dictElement) { }
 
     void evaluate(Transaction *t,
@@ -76,10 +76,9 @@ class Resource_DictElementRegexp : public Variable {
         std::vector<const VariableValue *> *l) override {
         t->m_collections.m_resource_collection->resolveRegularExpression(
             m_dictElement, t->m_collections.m_resource_collection_key,
-            t->m_rules->m_secWebAppId.m_value, l);
+            t->m_rules->m_secWebAppId.m_value, l, m_keyExclusion);
     }
 
-    Utils::Regex m_r;
     std::string m_dictElement;
 };
 
@@ -97,19 +96,19 @@ class Resource_DynamicElement : public Variable {
         t->m_collections.m_resource_collection->resolveMultiMatches(
             string,
             t->m_collections.m_resource_collection_key,
-            t->m_rules->m_secWebAppId.m_value, l);
+            t->m_rules->m_secWebAppId.m_value, l, m_keyExclusion);
     }
 
     void del(Transaction *t, std::string k) {
         t->m_collections.m_resource_collection->del(k,
-            t->m_collections.m_resource_collection_key);
+            t->m_collections.m_resource_collection_key,
+            t->m_rules->m_secWebAppId.m_value);
     }
 
     void storeOrUpdateFirst(Transaction *t, std::string var,
         std::string value) {
         t->m_collections.m_resource_collection->storeOrUpdateFirst(
-            var,
-            t->m_collections.m_resource_collection_key,
+            var, t->m_collections.m_resource_collection_key,
             t->m_rules->m_secWebAppId.m_value, value);
     }
 
@@ -117,7 +116,7 @@ class Resource_DynamicElement : public Variable {
 };
 
 
-}  // namespace Variables
+}  // namespace variables
 }  // namespace modsecurity
 
 #endif  // SRC_VARIABLES_RESOURCE_H_
