@@ -27,20 +27,14 @@
 namespace modsecurity {
 
 class Transaction;
-namespace Variables {
+namespace variables {
 
-class ResponseContentType : public Variable {
- public:
-    ResponseContentType()
-        : Variable("RESPONSE_CONTENT_TYPE") { }
-    void evaluate(Transaction *transaction,
-        Rule *rule,
-        std::vector<const VariableValue *> *l) {
-        transaction->m_variableResponseContentType.evaluate(l);
-    }
-};
 
-}  // namespace Variables
+DEFINE_VARIABLE(ResponseContentType, RESPONSE_CONTENT_TYPE,
+    m_variableResponseContentType)
+
+
+}  // namespace variables
 }  // namespace modsecurity
 
 #endif  // SRC_VARIABLES_RESPONSE_CONTENT_TYPE_H_
