@@ -27,21 +27,13 @@
 namespace modsecurity {
 
 class Transaction;
-namespace Variables {
+namespace variables {
 
-class Status : public Variable {
- public:
-    Status()
-        : Variable("STATUS") { }
 
-    void evaluate(Transaction *transaction,
-        Rule *rule,
-        std::vector<const VariableValue *> *l) {
-        transaction->m_variableResponseStatus.evaluate(l);
-    }
-};
+DEFINE_VARIABLE(Status, STATUS, m_variableResponseStatus)
 
-}  // namespace Variables
+
+}  // namespace variables
 }  // namespace modsecurity
 
 #endif  // SRC_VARIABLES_STATUS_H_
