@@ -31,11 +31,11 @@
 #include "modsecurity/transaction.h"
 
 namespace modsecurity {
-namespace Variables {
+namespace variables {
 
 void TimeWDay::evaluate(Transaction *transaction,
     Rule *rule,
-    std::vector<const collection::Variable *> *l) {
+    std::vector<const VariableValue *> *l) {
     char tstr[200];
     struct tm timeinfo;
     time_t timer;
@@ -48,10 +48,10 @@ void TimeWDay::evaluate(Transaction *transaction,
 
     transaction->m_variableTimeWDay.assign(tstr);
 
-    l->push_back(new collection::Variable(&m_retName,
+    l->push_back(new VariableValue(&m_retName,
         &transaction->m_variableTimeWDay));
 }
 
 
-}  // namespace Variables
+}  // namespace variables
 }  // namespace modsecurity
